import { FormGroup } from '@angular/forms';
import type { Observable } from 'rxjs';
import type { IActionOptions } from '../interfaces/action-options';
import type { IDynamicControl } from '../interfaces/dynamic-control';
import type { IDynamicForm } from '../interfaces/dynamic-form';
import type { IDynamicOverride } from '../interfaces/dynamic-override';
export declare class DynamicForm {
    private controls;
    private overrides;
    private formGroup;
    private config;
    private actions;
    private onSaveSubject;
    private onCloseSubject;
    private onResetSubject;
    private onChangeSubject;
    private onReloadSubject;
    private formChange;
    constructor(config: IDynamicForm);
    /**
     * Get FormGroup
     */
    get FormGroup(): FormGroup;
    /**
     * Get controls
     */
    get Controls(): IDynamicControl[];
    /**
     * Get action options
     */
    get Actions(): IActionOptions;
    /**
     * Get observable for save event
     * @returns Observable
     */
    get onSave(): Observable<unknown>;
    /**
     * Get observable for close event
     * @returns Observable
     */
    get onClose(): Observable<unknown>;
    /**
     * Get observable for reset event
     * @returns Observable
     */
    get onReset(): Observable<unknown>;
    /**
     * Get observable for change event
     * @returns Observable
     */
    get onChange(): Observable<unknown>;
    /**
     * Get observable for form reload event
     * @returns Observable
     */
    get onReload(): Observable<unknown>;
    /**
     * Init form
     */
    private initForm;
    /**
     * Reload form
     */
    reloadForm(_formGroup: FormGroup, _overrides: IDynamicOverride[]): void;
    /**
     * Trigger dynamicForm save event
     *
     */
    save(): void;
    /**
     * Trigger dynamicForm close event
     */
    close(): void;
    /**
     * Trigger dynamicForm reset event
     */
    reset(): void;
    /**
     * Clean form / reset
     */
    cleanForm(): void;
    /**
     * Reload labels
     */
    reloadLabels(): void;
    /**
     * Collect all errors from form controls
     * @returns string[]
     */
    collectErrors(): string[];
    /**
     * Map controls with overrides
     */
    private mapControls;
}
